powered by
constructing spatial weight matrix based on geocomplexity with spatial dependence
geocd_swm(sfj, wt = NULL, style = "B", ...)
A matrix
An sf object or spatial vector object that can be converted to sf by sf::st_as_sf().
sf
sf::st_as_sf()
(optional) Spatial weight matrix based on spatial adjacency or spatial distance relationships.
(optional) A character that can be B,W,C. More to see spdep::nb2mat(). Default is B.
B
W
C
spdep::nb2mat()
(optional) Other parameters passed to geocomplexity::geocd_vector().
geocomplexity::geocd_vector()
econineq = sf::read_sf(system.file('extdata/econineq.gpkg',package = 'geocomplexity')) wt_gc = geocd_swm(econineq) wt_gc[1:5,1:5]
Run the code above in your browser using DataLab